@@ -21,12 +21,12 @@ class PdpRepo:
         self.__policiesTablePolicyTypeFieldName = policiesTablePolicyTypeFieldName
         self.__policiesKeyPrefix = policiesKeyPrefix 
         self.__policiesDdbTableResource = _DYNAMODB_RESOURCE.Table(policiesTableName)
-        self.__logger = Logger()
+        self.__logger = Logger(child=True)
 
     def savePolicy(self, policy:Policy) -> None:
         policyDict = ObjectUtil.toDict(policy)
         policyDict[self.__policiesTableEntityUriFieldName] = self.__prefixKeyFieldValue(policy.entityUri)
-        policyDict[self.__policiesTablePolicyTypeFieldName] = self.__prefixKeyFieldValue(policy.policyType)
+        policyDict[self.__policiesTablePolicyTypeFieldName] = self.__prefixKeyFieldValue(policy.policyType.value)
         if self.__policiesTableEntityUriFieldName != _DEFAULT_ENTITY_URI_FIELD_NAME:
             del policyDict[_DEFAULT_ENTITY_URI_FIELD_NAME]
         if self.__policiesTablePolicyTypeFieldName != _DEFAULT_POLICY_TYPE_FIELD_NAME:
@@ -38,23 +38,23 @@ class PdpRepo:
         return policy
 
     def getPolicies(self, subjectUris:List[str], resourceUris:List[str]) -> List[Policy]:
-        policiesDict = _DYNAMODB_RESOURCE.batch_get_item(
-            RequestItems = {
-                self.__policiesTableName: {
-                    "Keys": [
-                        {
-                            self.__policiesTableEntityUriFieldName: prefixedUri,
-                            self.__policiesTablePolicyTypeFieldName: self.__prefixKeyFieldValue(PolicyType.SUBJECT.value)
-                        } for prefixedUri in self.__prefixEntityUris(subjectUris)
-                    ] + [
-                        {
-                            self.__policiesTableEntityUriFieldName: prefixedUri,
-                            self.__policiesTablePolicyTypeFieldName: self.__prefixKeyFieldValue(PolicyType.RESOURCE.value)
-                        } for prefixedUri in self.__prefixEntityUris(resourceUris)
-                    ]
-                }
+        batchGetRequestItemsDict = {
+            self.__policiesTableName: {
+                "Keys": [
+                    {
+                        self.__policiesTableEntityUriFieldName: prefixedUri,
+                        self.__policiesTablePolicyTypeFieldName: self.__prefixKeyFieldValue(PolicyType.SUBJECT.value)
+                    } for prefixedUri in self.__prefixEntityUris(subjectUris)
+                ] + [
+                    {
+                        self.__policiesTableEntityUriFieldName: prefixedUri,
+                        self.__policiesTablePolicyTypeFieldName: self.__prefixKeyFieldValue(PolicyType.RESOURCE.value)
+                    } for prefixedUri in self.__prefixEntityUris(resourceUris)
+                ]
             }
-        )
+        }
+        self.__logger.info(f"{batchGetRequestItemsDict=}")
+        policiesDict = _DYNAMODB_RESOURCE.batch_get_item(RequestItems = batchGetRequestItemsDict)
         self.__logger.info(f"{policiesDict=}")
         returnPolicies = []
         if self.__policiesTableName in policiesDict["Responses"]:
